Installation
============

Basic Installation
------------------

Clone the repository and install:

.. code-block:: bash

   git clone https://github.com/genomicsxai/alphagenome-pytorch
   pip install -e alphagenome-pytorch

Building documentation
----------------------

You can compile the documentation that you are reading now locally:

.. code-block:: bash

   pip install -e "alphagenome-pytorch[docs]"
   cd docs
   make html

The built documentation will be available at ``docs/_build/html/index.html``.
